@@ -5,23 +5,22 @@
 
 
 /**
-   File Name:          15.9.5.12.js
-   ECMA Section:       15.9.5.12
-   Description:        Date.prototype.getDay
+   File Name:          15.9.5.13.js
+   ECMA Section:       15.9.5.13
+   Description:        Date.prototype.getUTCDay
 
-
-   1.   Let t be this time value.
-   2.   If t is NaN, return NaN.
-   3.   Return WeekDay(LocalTime(t)).
+   1.Let t be this time value.
+   2.If t is NaN, return NaN.
+   3.Return WeekDay(t).
 
    Author:             christine@netscape.com
    Date:               12 november 1997
 */
 
-var SECTION = "15.9.5.12";
+var SECTION = "15.9.5.13";
 var VERSION = "ECMA_1";
 startTest();
-var TITLE   = "Date.prototype.getDay()";
+var TITLE   = "Date.prototype.getUTCDay()";
 
 writeHeaderToLog( SECTION + " "+ TITLE);
 
@@ -36,8 +35,8 @@ function addTestCase( t ) {
   for (var d = start; d < stop; d += msPerDay)
   {
     new TestCase( SECTION,
-                  "(new Date("+d+")).getDay()",
-                  WeekDay((LocalTime(d))),
-                  (new Date(d)).getDay() );
+                  "(new Date("+d+")).getUTCDay()",
+                  WeekDay((d)),
+                  (new Date(d)).getUTCDay() );
   }
 }
