@@ -5,7 +5,7 @@
 
 
 /**
-   File Name:          7.3-3.js
+   File Name:          7.3-4.js
    ECMA Section:       7.3 Comments
    Description:
 
@@ -14,18 +14,18 @@
    Date:               12 november 1997
 
 */
-var SECTION = "7.3-3";
+var SECTION = "7.3-4";
 var VERSION = "ECMA_1";
 startTest();
 var TITLE   = "Comments";
 
 writeHeaderToLog( SECTION + " "+ TITLE);
 
-var testcase =  new TestCase( SECTION,
-			      "source text directly following a single-line comment",
-			      "pass",
-			      "fail");
-// a comment string
-testcase.actual = "pass";
+var testcase = new TestCase( SECTION,
+			     "multiline comment ",
+			     "pass",
+			     "pass");
+
+/*testcase.actual = "fail";*/
 
 test();
