@@ -4,17 +4,12 @@
 /// "Use Terms").   Any redistribution of this code must retain the above
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch10/10.4/10.4.3/10.4.3-1-38gs.js
- * @description Strict - checking 'this' from a global scope (Anonymous FunctionExpression defined within a FunctionDeclaration with a strict directive prologue)
- * @onlyStrict
+ * @path ch10/10.4/10.4.3/10.4.3-1-82gs.js
+ * @description Strict - checking 'this' from a global scope (non-strict function declaration called by strict eval)
+ * @noStrict
  */
 
-function f1() {
-    "use strict";
-    return ((function () {
-        return typeof this;
-    })()==="undefined") && ((typeof this)==="undefined");
-}
-if (! f1()) {
+function f() { return this!==undefined;};
+if (! ((function () {"use strict"; return eval("f();");})()) ){
     throw "'this' had incorrect value!";
-}
\ No newline at end of file
+}
