@@ -4,19 +4,19 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch13/13.1/13.1-36-s.js
- * @description StrictMode - SyntaxError is thrown if 'eval' occurs as the function name of a FunctionDeclaration whose FunctionBody is in strict mode
+ * @path ch13/13.2/13.2-3-s.js
+ * @description StrictMode - Writing or reading from a property named 'arguments' of function objects is allowed under both strict and normal modes.
  * @onlyStrict
  */
 
 
 function testcase() {
+        "use strict";
 
-        try {
-            eval("function eval() { 'use strict'; };")
-            return false;
-        } catch (e) {
-            return e instanceof SyntaxError;
-        }
+        var foo = function () {
+            this.arguments = 12;
+        } 
+        var obj = new foo();
+        return obj.arguments === 12;
     }
 runTestCase(testcase);
